==> savane-1.0.2.tar.gz: savane/frontend/php/account/login.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: login.php,v 1.46 2004/03/28 18:11:57 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Header( "Expires: Wed, 11 Nov 1998 11:11:11 GMT");
Header( "Cache-Control: no-cache");
Header( "Cache-Control: must-revalidate");

require '../include/pre.php';
require '../include/account.php';

if ($GLOBALS['sys_https_host'] != "" && !session_issecure())
{
  #force use of SSL for login
  header('Location: '.$GLOBALS['sys_https_host'].$GLOBALS['sys_home'].'/account/login.php');
}

###### first check for valid login, if so, redirect

if ($login)
{
  # If we come from brother, it means that passwd is encrypted
  $crypted_pw = $from_brother;
  $success=session_login_valid($form_loginname,$form_pw,0,$cookie_for_a_year,$crypted_pw, $stay_in_ssl);
  if ($success)
    {
      /*
		You can now optionally stay in SSL mode
      */
      if ($GLOBALS['sys_https_host'] != "" && $stay_in_ssl)
	{
	  $http = "https";
	}
      else
	{
	  $http = "http";
	}

      # If a brother server exists, login there too, if we are not
      # already coming from there
      if ($GLOBALS['sys_brother_domain'] && $brotherhood)
	{
	  if (! $from_brother)
	    {
	      # Go there saying hello to your brother
	      # First, crypt the password.
	      # (Normally, users shouldn't use this feature
	      # unless they ever login at brother site).
	      $form_pw=crypt(md5($form_pw));
	      header ("Location: ".$http."://".$GLOBALS['sys_brother_domain'].$GLOBALS['sys_home']."/account/login.php?form_loginname=$form_loginname&form_pw=$form_pw&cookie_for_a_year=$cookie_for_a_year&from_brother=1&login=1&stay_in_ssl=$stay_in_ssl&brotherhood=1");
	      exit;
	    }
	  else
	    {
	      # We return to our brother 'my', where we login originally
	      header ("Location: ".$http."://".$GLOBALS['sys_brother_domain'].$GLOBALS['sys_home']."my/");
	      exit;
	    }
	}
      else
	{
	  # If No brother server exists, just go to 'my' page
	  header ("Location: ".$http."://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."my/");
	  exit;
	}

    }
}

## UNSECURE
##if ($session_hash)
##{
##  #nuke their old session
##  session_cookie('session_hash','');
## db_query("DELETE FROM session WHERE session_hash='$session_hash'");
##}

site_header(array('title'=>_("Login")));

if ($login && !$success)
{

  if ("Account Pending" == $feedback)
    {

      echo '<h3>'._("Pending Account").'</h3>';
      echo '<p>'._("Your account is currently pending your email confirmation. Visiting the link sent to you in this email will activate your account.").'</p>';
      echo '<p>'._("If you need this email resent, please click below and a confirmation email will be sent to the email address you provided in registration.").'</p>';
      echo '<p><a href="pending-resend.php?form_user='.$form_loginname.'">['._("Resend Confirmation Email").']</a></p>';

    }

}

if (session_issecure())
{
  echo '<p>'._("Cookies must be enabled past this point.").'</p>';
  echo '<p>'._("You will be connected with an SSL server and your password will not be visible to other users.").'</p>';
}

echo '<form action="'.$GLOBALS['sys_https_url'].'/account/login.php" method="post">';
echo '<input type="hidden" name="return_to" value="'.$return_to.'">';

echo '<div class="inputfield"><h5>'._("Login Name:").'</h5>';
echo '<input type="text" name="form_loginname" value="'.$form_loginname.'"></div>';

echo '<div class="inputfield"><h5>'._("Password").':</h5>';
echo '<input type="password" name="form_pw"></div>';

if (session_issecure())
{
  print '<p><input type="checkbox" name="stay_in_ssl" value="1" checked">';
  print _("Stay in SSL mode after login")."<br>\n";
  print '<i>'._("(Lynx, Emacs w3 and Microsoft Internet Explorer users will have intermittent SSL problems, so they should leave SSL after login. Gecko-based browser (Mozilla, Galeon, Netscape...) and Konqueror users should stay in SSL mode permanently for maximum security.)").'</i></p>';
}
else
{
  print "<p><input type=\"hidden\" name=\"stay_in_ssl\" value=\"0\">\n";
  print _("This server does not use SSL, so the password you sent may be viewed by other people. Do not use any important passwords").'.</p>';
}

print '<p><input type="checkbox" name="cookie_for_a_year" value="1">'._("Remember me").'<br>';
print '<i>'._("(For a year, your login information will be stored in a cookie. Use this only if you are using your own computer.)").'</i>';

if ($GLOBALS['sys_brother_domain'])
{
  print '<p><input type="checkbox" name="brotherhood" value="1">';
  printf (_("Login also in %s").'<br />', $GLOBALS['sys_brother_domain']);
  print '<i>';
  printf (_("(Do not use this if you are using kerberos. Do not use this until you already successfully logged in on %s, the result would be unpredictable.)"), $GLOBALS['sys_brother_domain']);
  print '</i>';
}

print '<p><input type="submit" name="login" value="'._("Login").'"></p>';
print '</form>';

print '<p><a href="lostpw.php">['._("Lost your password?").']</a></p>';
print '<p><a href="register.php">['._("New Account").']</a></p>';


$HTML->footer(array());

?>

==> savane-1.0.3.1.tar.gz: savane/frontend/php/account/login.php <==
<?php
# This file is part of the Savane project
# <http://gna.org/projects/savane/>
#
# $Id: login.php,v 1.49 2004/06/26 11:50:41 yeupou Exp $
#
#  Copyright 1999-2000 (c) The SourceForge Crew
#  Copyright 2000-2003 (c) Free Software Foundation
#
#  Copyright 2003-2004 (c) Mathieu Roy <yeupou--at--gnu.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.

Header( "Expires: Wed, 11 Nov 1998 11:11:11 GMT");
Header( "Cache-Control: no-cache");
Header( "Cache-Control: must-revalidate");

require '../include/pre.php';
require '../include/account.php';

if ($GLOBALS['sys_https_host'] != "" && !session_issecure())
{
  #force use of SSL for login
  header('Location: '.$GLOBALS['sys_https_host'].$GLOBALS['sys_home'].'/account/login.php');
}

###### first check for valid login, if so, redirect

if ($login)
{
  # If we come from brother, it means that passwd is encrypted
  $crypted_pw = $from_brother;
  $success=session_login_valid($form_loginname,$form_pw,0,$cookie_for_a_year,$crypted_pw, $stay_in_ssl);
  if ($success)
    {
      /*
		You can now optionally stay in SSL mode
      */
      if ($GLOBALS['sys_https_host'] != "" && $stay_in_ssl)
	{
	  $http = "https";
	}
      else
	{
	  $http = "http";
	}

      # If a brother server exists, login there too, if we are not
      # already coming from there
      if ($GLOBALS['sys_brother_domain'] && $brotherhood)
	{
	  if (! $from_brother)
	    {
	      # Go there saying hello to your brother
	      # First, crypt the password.
	      # (Normally, users shouldn't use this feature
	      # unless they ever login at brother site).
	      $form_pw=crypt(md5($form_pw));
	      header ("Location: ".$http."://".$GLOBALS['sys_brother_domain'].$GLOBALS['sys_home']."/account/login.php?form_loginname=$form_loginname&form_pw=$form_pw&cookie_for_a_year=$cookie_for_a_year&from_brother=1&login=1&stay_in_ssl=$stay_in_ssl&brotherhood=1");
	      exit;
	    }
	  else
	    {
	      # We return to our brother 'my', where we login originally
	      header ("Location: ".$http."://".$GLOBALS['sys_brother_domain'].$GLOBALS['sys_home']."my/");
	      exit;
	    }
	}
      else
	{
	  # If No brother server exists, just go to 'my' page
	  header ("Location: ".$http."://".$GLOBALS['sys_default_domain'].$GLOBALS['sys_home']."my/");
	  exit;
	}

    }
}

if ($session_hash)
{
   # Nuke their old session securely. 
   session_cookie('session_hash','');
   db_query("DELETE FROM session WHERE session_hash='$session_hash' AND user='$user_id'");
}

site_header(array('title'=>_("Login")));

if ($login && !$success)
{

  if ("Account Pending" == $feedback)
    {

      echo '<h3>'._("Pending Account").'</h3>';
      echo '<p>'._("Your account is currently pending your email confirmation. Visiting the link sent to you in this email will activate your account.").'</p>';
      echo '<p>'._("If you need this email resent, please click below and a confirmation email will be sent to the email address you provided in registration.").'</p>';
      echo '<p><a href="pending-resend.php?form_user='.$form_loginname.'">['._("Resend Confirmation Email").']</a></p>';

    }

}

if (session_issecure())
{
  echo '<p>'._("Cookies must be enabled past this point.").'</p>';
  echo '<p>'._("You will be connected with an SSL server and your password will not be visible to other users.").'</p>';
}

echo '<form action="'.$GLOBALS['sys_https_url'].'/account/login.php" method="post">';
echo '<input type="hidden" name="return_to" value="'.$return_to.'">';

echo '<div class="inputfield"><h5>'._("Login Name:").'</h5>';
echo '<input type="text" name="form_loginname" value="'.$form_loginname.'"></div>';

echo '<div class="inputfield"><h5>'._("Password").':</h5>';
echo '<input type="password" name="form_pw"></div>';

if (session_issecure())
{
  print '<p><input type="checkbox" name="stay_in_ssl" value="1" checked">';
  print _("Stay in SSL mode after login")."<br>\n";
  print '<i>'._("(Lynx, Emacs w3 and Microsoft Internet Explorer users will have intermittent SSL problems, so they should leave SSL after login. Gecko-based browser (Mozilla, Galeon, Netscape...) and Konqueror users should stay in SSL mode permanently for maximum security.)").'</i></p>';
}
else
{
  print "<p><input type=\"hidden\" name=\"stay_in_ssl\" value=\"0\">\n";
  print _("This server does not use SSL, so the password you sent may be viewed by other people. Do not use any important passwords").'.</p>';
}

print '<p><input type="checkbox" name="cookie_for_a_year" value="1">'._("Remember me").'<br>';
print '<i>'._("(For a year, your login information will be stored in a cookie. Use this only if you are using your own computer.)").'</i>';

if ($GLOBALS['sys_brother_domain'])
{
  print '<p><input type="checkbox" name="brotherhood" value="1">';
  printf (_("Login also in %s").'<br />', $GLOBALS['sys_brother_domain']);
  print '<i>';
  printf (_("(Do not use this if you are using kerberos. Do not use this until you already successfully logged in on %s, the result would be unpredictable.)"), $GLOBALS['sys_brother_domain']);
  print '</i>';
}

print '<p><input type="submit" name="login" value="'._("Login").'"></p>';
print '</form>';

print '<p><a href="lostpw.php">['._("Lost your password?").']</a></p>';
print '<p><a href="register.php">['._("New Account").']</a></p>';


$HTML->footer(array());

?>
